@@ -30,7 +30,7 @@ class DecimalClock(clock.Clock):
         clock.Clock.__init__(self, drawing_area)
 
     def draw_clock(self):
-        self.context.set_font_size(45)
+        self.context.set_font_size(int(self.text_scaling * 45))
         self.context.move_to(0, 35)
 
         h = self.time.hour
@@ -53,14 +53,14 @@ class DecimalClock(clock.Clock):
             self.context.stroke()
 
         if self.twelve_hour_mode :
-            self.context.set_font_size(20)
+            self.context.set_font_size(int(self.text_scaling * 20))
             self.context.move_to(self.text_width, 35)
             
             self.context.text_path(abrv)
             self.context.stroke()
 
     def resize(self):
-        self.context.set_font_size(45)
+        self.context.set_font_size(int(self.text_scaling * 45))
         if self.show_seconds :
             self.text_width = self.context.text_extents("00:00:00")[2]
         else:
@@ -69,7 +69,7 @@ class DecimalClock(clock.Clock):
         self.text_width *= 1.1
 
         if self.twelve_hour_mode :
-            self.context.set_font_size(20)
+            self.context.set_font_size(int(self.text_scaling * 20))
             self.abrv_width = self.context.text_extents("AM")[2]
             self.abrv_width *= 1.1
         else :
